C
C
C     **************************************************************
C
C     **************************************************************
C
C
      SUBROUTINE PKSRCH(SPEC,CENTIN,NCHAN,NPEAK,IPKSCH)
C
C     SEARCHES IPKSCH CHANNELS AROUND CENTIN VALUES TO GET
C     BETTER GUESS FOR PEAK CENTROIDS
C
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      DIMENSION SPEC(nchan), CENTIN(npeak),GUESS(30)
      DO 4001 I=1,NPEAK
      IMIN=CENTIN(I)-IPKSCH
      IMAX=CENTIN(I)+IPKSCH
      IMIN=MAX0(IMIN,1)
      IMAX=MIN0(IMAX,NCHAN)
      GUESS(I)=CENTIN(I)
      WX=0.0
      DO 4002 K=IMIN,IMAX
      IF(SPEC(K).LT.WX) GO TO 4002
      GUESS(I)=K
      WX=SPEC(K)
 4002 CONTINUE
 4001 CONTINUE
      KNPEAK=NPEAK-1
      DO 4003 I=1,KNPEAK
      KMIN=I+1
      DO 4004 K=KMIN,NPEAK
      IF(GUESS(I).NE.GUESS(K)) GO TO 4003
      GUESS(I)=CENTIN(I)
      GUESS(K)=CENTIN(K)
 4004 CONTINUE
 4003 CONTINUE
      DO 4005 I=1,NPEAK
      CENTIN(I)=GUESS(I)
 4005 CONTINUE
      RETURN
      END
